%bcond_with     gimp3

%define         moname        %{name}
%define         abi_version   %{?with_gimp3:2.99}%{?!with_gimp3:2.0}
%define         plugindir     %{_libdir}/gimp/%{abi_version}/plug-ins
%define         scriptdir     %{_datadir}/gimp/%{abi_version}/scripts

Name:           gimp-plugin-astronomy
Version:        0.11
Release:        %mkrel 1
Summary:        Astronomy plugins for the GIMP graphic editor
License:        GPLv2+
Group:          Graphics/Editors and Converters

URL:            https://github.com/JoesCat/gimp-plugin-astronomy
Source0:        https://github.com/JoesCat/gimp-plugin-astronomy/releases/download/%{version}/gimp-plugin-astronomy-%{version}.tar.bz2

BuildRequires:  gettext-devel
%if %{with gimp3}
BuildRequires:  pkgconfig(gimp-3.0)
BuildRequires:  pkgconfig(gtk+-3.0)
%else
BuildRequires:  pkgconfig(gimp-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
%endif
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gsl)

%if %{with gimp3}
Requires:       gimp3 >= 2.99
%else
Requires:       gimp >= 2.6.0
%endif

%description
Gimp Astronomy is a set of plug-ins for the Gimp graphic editor
intended for astronomical image processing. They support various basic
and more advanced tasks such as aligning and stacking images with
arithmetic, geometric, median, or sigma mean, removing dark frames and
dividing by a flat field. Some plug-gins are designed for creating
synthetic stars distribution or synthetic galaxy images.


%prep
%setup -q
%autopatch -p1

%if %{with gimp3}
# build for gimp-3.0
sed -i \
  -e 's/gimp-2.0/gimp-3.0/g' \
  -e 's/gimpui-2.0/gimpui-3.0/g' \
  -e 's/gimptool-2.0/gimptool-2.99/g' \
  configure.ac
%endif

# make autoreconf happy
sed -i \
  -e 's/AM_GNU_GETTEXT_VERSION\(([*.*]*)\)/AM_GNU_GETTEXT_REQUIRE_VERSION\1/' \
  -e 's/AM_GNU_GETTEXT_VERSION$/AM_GNU_GETTEXT_REQUIRE_VERSION([0.19.1])/' \
  configure.ac

%build
autoreconf -fi
export LIBS="-lm"
%configure \
    CPPFLAGS=-D_XOPEN_SOURCE=700
%make_build


%install
%make_install INSTALLDIR="%{buildroot}/%{plugindir}" \
      LOCALEDIR="%{buildroot}/%{_datadir}/locale"
%find_lang %{moname}


%files -f %{moname}.lang
%license COPYING
%doc %{_docdir}/%{name}/documentation.*
%doc README AUTHORS
%{scriptdir}/*.scm
%{plugindir}/astronomy-*


%changelog
* Mon Feb 06 2023 daviddavid <daviddavid> 0.11-1.mga8
+ Revision: 1938675
- reintroduce gimp-plugin-astronomy in mageia 8 (mga#28914)

* Thu Dec 29 2022 daviddavid <daviddavid> 0.11-2.mga9
+ Revision: 1927532
- rebuild for new gsl 2.7.1

* Tue Oct 04 2022 wally <wally> 0.11-1.mga9
+ Revision: 1894649
- new version 0.11 from new upstream fork (mga#30931)

* Sun Feb 16 2020 umeabot <umeabot> 0.9-6.mga8
+ Revision: 1529685
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Aug 27 2019 daviddavid <daviddavid> 0.9-5.mga8
+ Revision: 1433753
- rebuild for new gsl 2.6

* Sun Sep 23 2018 umeabot <umeabot> 0.9-4.mga7
+ Revision: 1297892
- Mageia 7 Mass Rebuild

* Wed Dec 27 2017 wally <wally> 0.9-3.mga7
+ Revision: 1185641
- rebuild for new gsl

* Sat Sep 30 2017 cjw <cjw> 0.9-2.mga7
+ Revision: 1161909
- patch2: fix build with gcc 7

* Tue May 02 2017 eatdirt <eatdirt> 0.9-1.mga6
+ Revision: 1098596
- Upgrade to version 0.9

* Tue Jan 26 2016 luigiwalser <luigiwalser> 0.8-7.mga6
+ Revision: 927763
- add patch to fix build with gsl version 2
- rebuild for gsl

* Wed Oct 15 2014 umeabot <umeabot> 0.8-6.mga5
+ Revision: 740397
- Second Mageia 5 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.8-5.mga5
+ Revision: 738814
- Mageia 5 Mass Rebuild

* Sun Apr 27 2014 eatdirt <eatdirt> 0.8-4.mga5
+ Revision: 618510
- Rebuild (old age)

* Sat Oct 19 2013 umeabot <umeabot> 0.8-3.mga4
+ Revision: 531958
- Mageia 4 Mass Rebuild

* Tue Aug 13 2013 eatdirt <eatdirt> 0.8-2.mga4
+ Revision: 466100
- Fix unimplemented features in description

* Mon Aug 12 2013 eatdirt <eatdirt> 0.8-1.mga4
+ Revision: 465743
- imported package gimp-plugin-astronomy


* Mon Aug 12 2013 Chris Ringeval <eatdirt@mageia.org> 0.8-1.mga4
  imported package gimp-plugin-astronomy
